/**
 * Copyright 2023 Velocity Team
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

const AWS = require('aws-sdk');

const testsConfig = (awsEndpoint) =>
  awsEndpoint
    ? {
        credentials: new AWS.Credentials('tests-kei-id', 'tests-key'),
        endpoint: awsEndpoint,
      }
    : {};

const createSesClient = ({ awsRegion, awsEndpoint }) =>
  new AWS.SES({
    apiVersion: '2010-12-01',
    region: awsRegion,
    ...testsConfig(awsEndpoint),
  });

const createSesV2Client = ({ awsRegion }) =>
  new AWS.SESV2({
    apiVersion: '2019-09-27',
    region: awsRegion,
  });

const createDynamoDbClient = ({ awsRegion, awsEndpoint }) =>
  new AWS.DynamoDB({
    apiVersion: '2012-08-10',
    region: awsRegion,
    ...testsConfig(awsEndpoint),
  });

const createDynamoDbDocumentClient = ({ awsRegion, awsEndpoint }) =>
  new AWS.DynamoDB.DocumentClient({
    apiVersion: '2012-08-10',
    region: awsRegion,
    ...testsConfig(awsEndpoint),
  });

const createS3Client = ({
  awsRegion,
  awsEndpoint,
  accessKeyId,
  secretAccessKey,
  isTest,
}) =>
  new AWS.S3({
    apiVersion: '2006-03-01',
    region: awsRegion,
    signatureVersion: 'v4',
    accessKeyId,
    secretAccessKey,
    s3ForcePathStyle: isTest,
    ...testsConfig(awsEndpoint),
  });

const createSnsClient = ({ awsRegion, awsEndpoint }) =>
  new AWS.SNS({
    apiVersion: '2010-03-31',
    region: awsRegion,
    ...testsConfig(awsEndpoint),
  });

module.exports = {
  createSnsClient,
  createSesClient,
  createSesV2Client,
  createDynamoDbClient,
  createDynamoDbDocumentClient,
  createS3Client,
};
